@@ -4,7 +4,7 @@
 modname = 'seda'
 distname = 'cubicweb-seda'
 
-numversion = (0, 18, 1)
+numversion = (0, 21, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -14,7 +14,7 @@ description = 'Data Exchange Standard for Archival'
 web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.25.4, < 3.27',
+    'cubicweb': ">= 3.25.4, < 3.35.0",
     'six': '>= 1.4.0',
     'yams': '< 0.46.0',
     'cubicweb-eac': '>= 0.8.3, < 0.9.0',
